@@ -5,7 +5,7 @@ use indexmap::set::IndexSet;
 
 use super::matchers::Matcher;
 use crate::completion::{Completer, CompletionContext, Suggestion};
-use crate::evaluation_context::EvaluationContext;
+use nu_engine::EvaluationContext;
 
 pub struct CommandCompleter;
 
